#include <stdio.h>
#include <stdlib.h>
#include <time.h>

typedef double real;
typedef double* vector;


void accumulate(vector b, const vector a, size_t n) {
   size_t j;
   real s = 0;
   for (j = 0; j < n; ++j) {
      s += a[j];
      b[j] = s;
   }
}

void output_vector(FILE *f, const vector a, const char* title, const char* format, size_t n) {
   size_t j;
   fputs(title, f);
   //fprintf(f, "aaa");
   for (j = 0; j < n; ++j) {
      fprintf(f, format, a[j]);
   }
   fprintf(f, "\n");
}

vector create_zero_vector(size_t n) {
   return (real*) calloc(n, sizeof(real));
}

void free_vector(vector a) {
   free(a);
}

void init_random() {
   time_t t;
   srand((unsigned) time(&t));
}

real rand_real() {
   return -1 + 2 * (((real) rand()) / RAND_MAX);
}

int rand_int(int min_value, int max_value) {
   return (rand() % (max_value - min_value + 1)) + min_value;
}

void fill_vector_rand(vector a, size_t n) {
   size_t j;
   for (j = 0; j < n; ++j) {
      a[j] = rand_real();
   }
}

void fill_vector_rand_int(vector a, int min_value, int max_value, size_t n) {
   size_t j;
   for (j = 0; j < n; ++j) {
      a[j] = rand_int(min_value, max_value);
   }
}

int main() {
   size_t n = 5;
   vector a = create_zero_vector(n);
   vector b = create_zero_vector(n);
   init_random();
   //fill_vector_rand(a, n);
   fill_vector_rand_int(a, -10, 10, n);
   accumulate(b, a, n);
   output_vector(stdout, a, "Vector a:\n", "%8.3f ", n);
   output_vector(stdout, b, "Vector b:\n", "%8.3f ", n);
   free_vector(a);
   free_vector(b);
}

